WooTerm class

A category or tag a product belongs to.

Constructors

WooTerm({required int id, required String name, required String slug})
Creates a term.
const
WooTerm.fromJson(Map<String, Object?> json)
Reads WooCommerce's representation.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → int
The term id.
final
name → String
Its display name.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slug → String
Its URL slug.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited