WooProductOrderBy enum
How to sort a product listing.
Values
- date → const WooProductOrderBy
-
By publication date.
- id → const WooProductOrderBy
-
By product id.
- title → const WooProductOrderBy
-
By name.
- slug → const WooProductOrderBy
-
By URL slug.
- price → const WooProductOrderBy
-
By price.
- popularity → const WooProductOrderBy
-
By popularity, which WooCommerce takes to mean total sales.
- rating → const WooProductOrderBy
-
By average review score.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wireName → String
-
The string WooCommerce expects.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
WooProductOrderBy> - A constant List of the values in this enum, in order of their declaration.